==> vertex_protocol-1.0.0.tar.gz: vertex_protocol-1.0.0/vertex_protocol/client/apis/subaccount/query.py <==
from vertex_protocol.client.apis.base import VertexBaseAPI
from vertex_protocol.engine_client.types.query import (
    FeeRatesData,
    QuerySubaccountInfoTx,
    SubaccountInfoData,
)
from vertex_protocol.indexer_client.types.query import (
    IndexerLinkedSignerRateLimitData,
    IndexerTokenRewardsData,
)


class SubaccountQueryAPI(VertexBaseAPI):
    """
    Provides functionalities for querying data related to subaccounts in the Vertex Protocol.

    Inherits from VertexBaseAPI, which provides a basic context setup for accessing Vertex Clearinghouse.
    This class extends the base class to provide specific functionalities for querying data related to subaccounts.

    Attributes:
        context (VertexClientContext): Provides connectivity details for accessing Vertex APIs.
    """

    def get_engine_subaccount_summary(
        self, subaccount: str, txs: list[QuerySubaccountInfoTx] | None = None
    ) -> SubaccountInfoData:
        """
        Retrieve a comprehensive summary of the specified subaccount's state as per the off-chain engine.

        You can optionally provide a list of txs to get an estimated view of your subaccount.

        Args:
            subaccount (str): Unique identifier for the subaccount.

            txs (list[QuerySubaccountInfoTx], optional): Optional list of transactions for the subaccount.

        Returns:
            SubaccountInfoData: A data class object containing detailed state information about the queried subaccount.
        """
        return self.context.engine_client.get_subaccount_info(subaccount, txs)

    def get_subaccount_fee_rates(self, subaccount: str) -> FeeRatesData:
        """
        Retrieve the fee rates associated with a specific subaccount from the off-chain engine.

        Args:
            subaccount (str): Unique identifier for the subaccount.

        Returns:
            FeeRatesData: A data class object containing detailed fee rates data for the specified subaccount.
        """
        return self.context.engine_client.get_fee_rates(subaccount)

    def get_subaccount_token_rewards(self, address: str) -> IndexerTokenRewardsData:
        """
        Query the $VRTX token rewards accumulated per epoch for a specified wallet from the indexer.

        Args:
            address (str): Wallet address to be queried.

        Returns:
            IndexerTokenRewardsData: A data class object containing detailed information about the accrued token rewards.
        """
        return self.context.indexer_client.get_token_rewards(address)

    def get_subaccount_linked_signer_rate_limits(
        self, subaccount: str
    ) -> IndexerLinkedSignerRateLimitData:
        """
        Retrieve the current linked signer and their rate limit for a specified subaccount from the indexer.

        Args:
            subaccount (str): Unique identifier for the subaccount.

        Returns:
            IndexerLinkedSignerRateLimitData: A data class object containing information about the current linked signer and their rate limits for the queried subaccount.
        """
        return self.context.indexer_client.get_linked_signer_rate_limits(subaccount)

==> vertex_protocol-1.1.3.tar.gz: vertex_protocol-1.1.3/vertex_protocol/client/apis/subaccount/query.py <==
from typing import Optional
from vertex_protocol.client.apis.base import VertexBaseAPI
from vertex_protocol.engine_client.types.query import (
    FeeRatesData,
    QuerySubaccountInfoTx,
    SubaccountInfoData,
)
from vertex_protocol.indexer_client.types.query import (
    IndexerLinkedSignerRateLimitData,
    IndexerTokenRewardsData,
)


class SubaccountQueryAPI(VertexBaseAPI):
    """
    Provides functionalities for querying data related to subaccounts in the Vertex Protocol.

    Inherits from VertexBaseAPI, which provides a basic context setup for accessing Vertex Clearinghouse.
    This class extends the base class to provide specific functionalities for querying data related to subaccounts.

    Attributes:
        context (VertexClientContext): Provides connectivity details for accessing Vertex APIs.
    """

    def get_engine_subaccount_summary(
        self, subaccount: str, txs: Optional[list[QuerySubaccountInfoTx]] = None
    ) -> SubaccountInfoData:
        """
        Retrieve a comprehensive summary of the specified subaccount's state as per the off-chain engine.

        You can optionally provide a list of txs to get an estimated view of your subaccount.

        Args:
            subaccount (str): Unique identifier for the subaccount.

            txs (list[QuerySubaccountInfoTx], optional): Optional list of transactions for the subaccount.

        Returns:
            SubaccountInfoData: A data class object containing detailed state information about the queried subaccount.
        """
        return self.context.engine_client.get_subaccount_info(subaccount, txs)

    def get_subaccount_fee_rates(self, subaccount: str) -> FeeRatesData:
        """
        Retrieve the fee rates associated with a specific subaccount from the off-chain engine.

        Args:
            subaccount (str): Unique identifier for the subaccount.

        Returns:
            FeeRatesData: A data class object containing detailed fee rates data for the specified subaccount.
        """
        return self.context.engine_client.get_fee_rates(subaccount)

    def get_subaccount_token_rewards(self, address: str) -> IndexerTokenRewardsData:
        """
        Query the $VRTX token rewards accumulated per epoch for a specified wallet from the indexer.

        Args:
            address (str): Wallet address to be queried.

        Returns:
            IndexerTokenRewardsData: A data class object containing detailed information about the accrued token rewards.
        """
        return self.context.indexer_client.get_token_rewards(address)

    def get_subaccount_linked_signer_rate_limits(
        self, subaccount: str
    ) -> IndexerLinkedSignerRateLimitData:
        """
        Retrieve the current linked signer and their rate limit for a specified subaccount from the indexer.

        Args:
            subaccount (str): Unique identifier for the subaccount.

        Returns:
            IndexerLinkedSignerRateLimitData: A data class object containing information about the current linked signer and their rate limits for the queried subaccount.
        """
        return self.context.indexer_client.get_linked_signer_rate_limits(subaccount)
